# 进度条模块
import os
import time
import requests

'''

'''
def progressbar(url, filename, parentpath='', redownload=False):
    if parentpath:
        if not os.path.exists(parentpath):  # 看是否有该文件夹，没有则创建文件夹
            os.mkdir(parentpath)
    filepath = parentpath + ('' if (not parentpath) or (parentpath.endswith('\\') or parentpath.endswith(
        '/')) else '\\') + filename  # 设置图片name，注：必须加上扩展名
    if not redownload:
        if os.path.exists(filepath):
            print(f' Download {filename} completed! exist,ignore')
            return

    start = time.time()  # 下载开始时间
    response = requests.get(url, stream=True)  # stream=True必须写上
    size = 0  # 初始化已下载大小
    chunk_size = 1024  # 每次下载的数据大小
    content_size = int(response.headers['content-length'])  # 下载文件总大小
    try:
        if response.status_code == 200:  # 判断是否响应成功
            print('Start download,[File size]:{size:.2f} MB'.format(
                size=content_size / chunk_size / 1024))  # 开始下载，显示下载文件大小

            with open(filepath, 'wb') as file:  # 显示进度条
                for data in response.iter_content(chunk_size=chunk_size):
                    file.write(data)
                    size += len(data)
                    print('\r' + '[下载进度]:%s%.2f%%' % (
                        '>' * int(size * 50 / content_size), float(size / content_size * 100)), end=' ')
        end = time.time()  # 下载结束时间
        print(f'Download {filename} completed!,times: %.2f秒' % (end - start))  # 输出下载用时时间
    except Exception as e:
        raise Exception(f"error download:{str(e)}")




def quicksort(array, vs, big_to_small=1):
    if len(array) < 2:
        return array
    else:
        index = len(array) // 2
        # pivot = array[index]  # 在数列中，选择一个元素作为基准，或者叫比较值
        pivot_v = vs[index]
        equals = []
        # equals.append(pivot)
        # array.remove(pivot)  # 在原数组中把比较值移除
        less, greater = [], []  # 定义基准值左右两个列表
        less_vs, greater_vs = [], []
        for i in range(len(array)):
            iv = vs[i]
            if iv < pivot_v:  # 小于基准值的放一侧
                less.append(array[i])
                less_vs.append(iv)
            elif iv > pivot_v:
                greater.append(array[i])  # 大于基准值的放另一侧
                greater_vs.append(iv)
            else:
                equals.append(array[i])

        if big_to_small == 1:
            return quicksort(greater, greater_vs) + equals + quicksort(less, less_vs)
        else:
            return quicksort(less, less_vs) + equals + quicksort(greater, greater_vs)



from setuptools import setup
from setuptools import find_packages
# import gediaoutils
# https://zhuanlan.zhihu.com/p/115302375
VERSION = '0.0.2'
with open('readme.md',encoding='utf-8') as f:
    LONG_DESCRIPTION = f.read()

setup(
    name='gediao-utils',  # package name
    version=VERSION,  # package version
    description='xuxy utils package',  # package description
    packages=find_packages(),
    author="色调呀",
    author_email="1059738716@qq.com",
    url="https://gitee.com/ukihi/gediao-open-python-utils",
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    zip_safe=False,
    package_data={
        # 引入任何包下面的 *.txt、*.rst 文件
        "": ["*.txt", "*.rst"],
        # 引入 hello 包下面的 *.msg 文件
        # "hello": ["*.msg"],
    },
    # install_requires=[
    #     "Werkzeug>=0.15",
    #     "Jinja2>=2.10.1",
    #     "itsdangerous>=0.24",
    #     "click>=5.1",
    # ],
)

